@@ -4,7 +4,7 @@ import sys
 from typing import Any, Dict
 
 name = "code-wake-sql13-store"
-version = "0.2.0"
+version = "0.2.1"
 author = "Michael Wright"
 author_email = "mjw@methodanalysis.com"
 description = "Code Wake SQL Academy 1.3 store adapter"
@@ -23,9 +23,9 @@ entry_points: Dict[str, Any] = {
 python_requires = ">=3.6"
 install_requires = [
     "sqlalchemy<1.4.0",
-    "sqlalchemy-utils==0.38.2",
+    "sqlalchemy-utils>=0.36.0",
     "bencode.py~=4.0.0",
-    "code-wake~=0.1.0",
+    "code-wake~=0.2.0",
 ]
 
 extras_require = {
