@@ -413,3 +413,22 @@ class Sql13Store:
             session.expunge_all()
 
             return event_records
+
+    def get_processes(
+        self,
+        app_id: Optional[int] = None,
+        from_ts: Optional[float] = None,
+        to_ts: Optional[float] = None,
+    ) -> Optional[Sql13Store.Process]:
+        with self.session() as session:
+            query = session.query(self.Process)
+            if app_id is not None:
+                query = query.filter(self.Process.app_id == app_id)
+            if from_ts is not None:
+                query = query.filter(self.Process.run_ts >= from_ts)
+            if to_ts is not None:
+                query = query.filter(self.Process.run_ts < to_ts)
+
+            process_records = query.all()
+            session.expunge_all()
+            return process_records
